@@ -82,6 +82,16 @@ class LIF(nn.Module):
 
         return spk, syn, mem
 
+    @staticmethod
+    def init_lapicque(batch_size, *args):
+        """Used to initialize mem and spk.
+        *args are the input feature dimensions.
+        E.g., ``batch_size=128`` and input feature of size=1x28x28 would require ``init_lapicque(128, 1, 28, 28)``."""
+        mem = torch.zeros((batch_size, *args), device=device, dtype=dtype)
+        spk = torch.zeros((batch_size, *args), device=device, dtype=dtype)
+
+        return spk, mem
+
     @staticmethod
     def init_srm0(batch_size, *args):
         """Used to initialize syn_pre, syn_post, mem and spk.
@@ -313,6 +323,163 @@ class Stein(LIF):
                 cls.instances[layer].mem = torch.zeros_like(cls.instances[layer].mem)
 
 
+class Lapicque(LIF):
+    """
+    An extension of Lapicque's experimental comparison between extracellular nerve fibers and an RC circuit.
+    It is equivalent to Stein's model without synaptic current dynamics.
+    Input stimulus is integrated by membrane potential which decays exponentially with a rate of beta.
+    For :math:`U[T] > U_{\\rm thr} ⇒ S[T+1] = 1`.
+
+    If `reset_mechanism = "subtract"`, then :math:`U[t+1]` will have `threshold` subtracted from it whenever the neuron emits a spike:
+
+    .. math::
+
+            U[t+1] = βU[t] + I_{\\rm in}[t+1] - RU_{\\rm thr}
+
+    If `reset_mechanism = "zero"`, then :math:`U[t+1]` will be set to `0` whenever the neuron emits a spike:
+
+    .. math::
+
+            U[t+1] = βU[t] + I_{\\rm in}[t+1] - R(βU[t] + I_{\\rm in}[t+1])
+
+    * :math:`I_{\\rm in}` - Input current
+    * :math:`U` - Membrane potential
+    * :math:`U_{\\rm thr}` - Membrane threshold
+    * :math:`R` - Reset mechanism: if active, :math:`R = 1`, otherwise :math:`R = 0`
+    * :math:`β` - Membrane potential decay rate
+
+    Example::
+
+        import torch
+        import torch.nn as nn
+        import snntorch as snn
+
+        beta = 0.5
+
+        # Define Network
+        class Net(nn.Module):
+            def __init__(self):
+                super().__init__()
+
+                # initialize layers
+                self.fc1 = nn.Linear(num_inputs, num_hidden)
+                self.lif1 = snn.Lapicque(beta=beta)
+                self.fc2 = nn.Linear(num_hidden, num_outputs)
+                self.lif2 = snn.Lapicque(beta=beta)
+
+            def forward(self, x, mem1, spk1, mem2):
+                cur1 = self.fc1(x)
+                spk1, mem1 = self.lif1(cur1, mem1)
+                cur2 = self.fc2(spk1)
+                spk2, mem2 = self.lif2(cur2, mem2)
+                return mem1, spk1, mem2, spk2
+
+
+    For further reading, see:
+
+    *L. Lapicque (1907) Recherches quantitatives sur l'excitation électrique des nerfs traitée comme une polarisation. J. Physiol. Pathol. Gen. 9, pp. 620-635. (French) *
+
+    *N. Brunel and M. C. Van Rossum (2007) Lapicque's 1907 paper: From frogs to integrate-and-fire. Biol. Cybern. 97, pp. 337-339. (English)*
+
+    Note: Although Lapicque did not formally introduce this as an integrate-and-fire neuron model, we pay homage to him driving the RC circuit directly with a battery due to his lack of a current source stimulus that could mimic the dynamics of synaptic current."""
+
+    def __init__(
+        self,
+        beta,
+        threshold=1.0,
+        num_inputs=False,
+        spike_grad=None,
+        batch_size=False,
+        hidden_init=False,
+        inhibition=False,
+        reset_mechanism="subtract",
+    ):
+        super(Stein, self).__init__(
+            beta, threshold, spike_grad, inhibition, reset_mechanism
+        )
+
+        self.num_inputs = num_inputs
+        self.batch_size = batch_size
+        self.hidden_init = hidden_init
+
+        if self.hidden_init:
+            if not self.num_inputs:
+                raise ValueError(
+                    "num_inputs must be specified to initialize hidden states as instance variables."
+                )
+            elif not self.batch_size:
+                raise ValueError(
+                    "batch_size must be specified to initialize hidden states as instance variables."
+                )
+            elif hasattr(self.num_inputs, "__iter__"):
+                self.spk, self.mem = self.init_lapicque(
+                    self.batch_size, *(self.num_inputs)
+                )  # need to automatically call batch_size
+            else:
+                self.spk, self.mem = self.init_lapicque(
+                    self.batch_size, self.num_inputs
+                )
+        if self.inhibition:
+            if not self.batch_size:
+                raise ValueError(
+                    "batch_size must be specified to enable firing inhibition."
+                )
+
+    def forward(self, input_, syn, mem):
+        if not self.hidden_init:
+            if self.inhibition:
+                spk, reset = self.fire_inhibition(self.batch_size, mem)
+            else:
+                spk, reset = self.fire(mem)
+
+            if self.reset_mechanism == "subtract":
+                mem = self.beta * mem + input_ - reset * self.threshold
+
+            elif self.reset_mechanism == "zero":
+                mem = self.beta * mem + input_ - reset * (self.beta * mem + input_)
+
+            return spk, mem
+
+        # intended for truncated-BPTT where instance variables are hidden states
+        if self.hidden_init:
+            if self.inhibition:
+                self.spk, self.reset = self.fire_inhibition(self.batch_size, self.mem)
+            else:
+                self.spk, self.reset = self.fire(self.mem)
+
+            if self.reset_mechanism == "subtract":
+                self.mem = self.beta * self.mem + input_ - self.reset * self.threshold
+
+            elif self.reset_mechanism == "zero":
+                self.mem = (
+                    self.beta * self.mem
+                    + input_
+                    - self.reset * (self.beta * self.mem + input_)
+                )
+
+            return self.spk, self.mem
+
+    @classmethod
+    def detach_hidden(cls):
+        """Returns the hidden states, detached from the current graph.
+        Intended for use in truncated backpropagation through time where hidden state variables are instance variables."""
+
+        for layer in range(len(cls.instances)):
+            if isinstance(cls.instances[layer], Lapicque):
+                cls.instances[layer].spk.detach_()
+                cls.instances[layer].mem.detach_()
+
+    @classmethod
+    def zeros_hidden(cls):
+        """Used to clear hidden state variables to zero.
+        Intended for use where hidden state variables are instance variables."""
+
+        for layer in range(len(cls.instances)):
+            if isinstance(cls.instances[layer], Lapicque):
+                cls.instances[layer].spk = torch.zeros_like(cls.instances[layer].spk)
+                cls.instances[layer].mem = torch.zeros_like(cls.instances[layer].mem)
+
+
 class SRM0(LIF):
     """
     Simplified Spike Response Model (:math:`0^{\\rm th}`` order) of the leaky integrate and fire neuron.
